==> haskell-descriptive-0.9.5-220-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 descriptive
version:              0.9.5
visibility:           public
id:                   descriptive-0.9.5-HzbDpsNiHtsBxtcWNPmzLR
key:                  descriptive-0.9.5-HzbDpsNiHtsBxtcWNPmzLR
license:              BSD-3-Clause
copyright:            2015 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
stability:            Experimental
homepage:             https://github.com/chrisdone/descriptive
synopsis:
    Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.

description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.

category:             Parsing
abi:                  58e5e637d2a371ead6d3d29479297e56
exposed:              True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options

hidden-modules:       Descriptive.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/descriptive-0.9.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/descriptive-0.9.5
hs-libraries:         HSdescriptive-0.9.5-HzbDpsNiHtsBxtcWNPmzLR
depends:
    aeson-1.5.6.0-8KXcI8eaJDb23YvdvZt7uT base-4.14.1.0
    bifunctors-5.5.10-FFjmpBCfpfxJflsLc7ad6R containers-0.6.2.1
    mtl-2.2.2 scientific-0.3.6.2-21jjdCL1aCqC58ACrk6SAS text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.0-9sHYkvizLwxkl2zr3W4dm

haddock-interfaces:   /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html:         /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.5-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 descriptive
version:              0.9.5
visibility:           public
id:                   descriptive-0.9.5-cBannib9EKC4jLJ4QmUUS
key:                  descriptive-0.9.5-cBannib9EKC4jLJ4QmUUS
license:              BSD-3-Clause
copyright:            2015 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
stability:            Experimental
homepage:             https://github.com/chrisdone/descriptive
synopsis:
    Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.

description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.

category:             Parsing
abi:                  12e77c75f153253440bb7424d85da565
exposed:              True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options

hidden-modules:       Descriptive.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/descriptive-0.9.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/descriptive-0.9.5
hs-libraries:         HSdescriptive-0.9.5-cBannib9EKC4jLJ4QmUUS
depends:
    aeson-1.5.6.0-4fHNEU34DqGLin6g6nejhx base-4.14.1.0
    bifunctors-5.5.10-B8UIjmNWbeOFg7Kx6s2BAH containers-0.6.2.1
    mtl-2.2.2 scientific-0.3.6.2-LBtXCOlSrNBHDdPHk4MvS7 text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.0-DZd2wim9OGg7KbOKVPP1I9

haddock-interfaces:   /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html:         /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
